# -*- coding: utf-8 -*-
import law
import luigi
import logging
import os
import re

from functools import partial

from .FastProd import FastProd
from ..util import working_directory

from analysis.framework import Task, SpaceSeparatedListParameter

logger = logging.getLogger(__name__)
working_directory = partial(working_directory, logger=logger)


class CopyTables(Task, law.LocalWorkflow):
    force = luigi.BoolParameter(default=False)

    merge_dir = luigi.Parameter(default='grids')

    default_channels = ["LO", "R", "V", "RRa", "RRb", "RV", "VV"]
    channels = SpaceSeparatedListParameter(
        default=default_channels,
        cls=luigi.Parameter,
        choices=("LO", "R", "V", "RRa", "RRb", "RV", "VV")
    )

    def create_branch_map(self):
        """Branch data dicts. Each branch should correspond to exactly one output."""
        return FastProd.req(self).branch_map

    def workflow_requires(self):
        if self.force:
            return {"fastprod": FastProd.req(self, acceptance=0)}
        else:
            return {"fastprod": FastProd.req(self)}

    def output(self):
        basename = FastProd(branch=self.branch).output().basename
        outfile = re.sub('.gz$', '', basename)
        outfile = re.sub('.tar$', '', outfile) + '.log'
        return law.LocalFileTarget(
            '{}/{}/{}/{}'.format(
                self.merge_dir, self.name,
                self.branch_data['channel'], outfile
            )
        )

    def run(self):
        self.output().parent.touch()
        with working_directory(self.output().parent.path):
            inp = FastProd(branch=self.branch).output()
            if not inp.exists():
                logger.warning('FastProd result not found: %s (branch %s)', inp, self.branch)
            else:
                logger.info('Copying FastProd result: %s', inp)
                inp.load('')
